# `relationalai.std.math`

The `relationalai.std.math` namespace contains mathematical functions.

- [`math.abs()`](./abs.md)
- [`math.acos()`](./acos.md)
- [`math.asin()`](./asin.md)
- [`math.atan()`](./atan.md)
- [`math.isclose()`](./isclose.md)
- [`math.ceil()`](./ceil.md)
- [`math.cbrt()`](./cbrt.md)
- [`math.cos()`](./cos.md)
- [`math.degrees()`](./degrees.md)
- [`math.floor()`](./floor.md)
- [`math.log()`](./log.md)
- [`math.radians()`](./radians.md)
- [`math.sign()`](./sign.md)
- [`math.sin()`](./sin.md)
- [`math.sqrt()`](./sqrt.md)
- [`math.tan()`](./tan.md)
- [`math.trunc_divide()`](./trunc_divide.md)
